@@ -17,10 +17,10 @@ from curifactory.manager import ArtifactManager
         (
             dict(experiment_name="test", parameters_list=["params1", "params2"]),
             dict(
-                store_entire_run=False,
+                store_full=False,
                 dry=False,
                 dry_cache=False,
-                custom_name=None,
+                prefix=None,
                 run_line="experiment test -p params1 -p params2",
                 parallel_lock=None,
                 parallel_mode=False,
@@ -31,10 +31,10 @@ from curifactory.manager import ArtifactManager
         (
             dict(experiment_name="test", parameters_list=[]),
             dict(
-                store_entire_run=False,
+                store_full=False,
                 dry=False,
                 dry_cache=False,
-                custom_name=None,
+                prefix=None,
                 run_line="experiment test",
                 parallel_lock=None,
                 parallel_mode=False,
@@ -49,10 +49,10 @@ from curifactory.manager import ArtifactManager
                 cache_dir_override="test/examples/data/superspecialcache",
             ),
             dict(
-                store_entire_run=False,
+                store_full=False,
                 dry=False,
                 dry_cache=False,
-                custom_name=None,
+                prefix=None,
                 run_line="experiment test -p params1 --cache test/examples/data/superspecialcache",
                 parallel_lock=None,
                 parallel_mode=False,
@@ -64,13 +64,13 @@ from curifactory.manager import ArtifactManager
             dict(
                 experiment_name="test",
                 parameters_list=["params1"],
-                store_entire_run=True,
+                store_full=True,
             ),
             dict(
-                store_entire_run=True,
+                store_full=True,
                 dry=False,
                 dry_cache=False,
-                custom_name=None,
+                prefix=None,
                 run_line="experiment test -p params1 --store-full",
                 parallel_lock=None,
                 parallel_mode=False,
@@ -86,10 +86,10 @@ from curifactory.manager import ArtifactManager
                 dry_cache=True,
             ),
             dict(
-                store_entire_run=False,
+                store_full=False,
                 dry=True,
                 dry_cache=True,
-                custom_name=None,
+                prefix=None,
                 run_line="experiment test -p params1 --dry --dry-cache",
                 parallel_lock=None,
                 parallel_mode=False,
@@ -101,14 +101,14 @@ from curifactory.manager import ArtifactManager
             dict(
                 experiment_name="test",
                 parameters_list=["params1"],
-                custom_name="custom_test",
+                prefix="custom_test",
             ),
             dict(
-                store_entire_run=False,
+                store_full=False,
                 dry=False,
                 dry_cache=False,
-                custom_name="custom_test",
-                run_line="experiment test -p params1 --name custom_test",
+                prefix="custom_test",
+                run_line="experiment test -p params1 --prefix custom_test",
                 parallel_lock=None,
                 parallel_mode=False,
                 lazy=False,
@@ -118,10 +118,10 @@ from curifactory.manager import ArtifactManager
         (
             dict(experiment_name="test", parameters_list=["params1"], lazy=True),
             dict(
-                store_entire_run=False,
+                store_full=False,
                 dry=False,
                 dry_cache=False,
-                custom_name=None,
+                prefix=None,
                 run_line="experiment test -p params1 --lazy",
                 parallel_lock=None,
                 parallel_mode=False,
@@ -132,10 +132,10 @@ from curifactory.manager import ArtifactManager
         (
             dict(experiment_name="test", parameters_list=["params1"], ignore_lazy=True),
             dict(
-                store_entire_run=False,
+                store_full=False,
                 dry=False,
                 dry_cache=False,
-                custom_name=None,
+                prefix=None,
                 run_line="experiment test -p params1 --ignore-lazy",
                 parallel_lock=None,
                 parallel_mode=False,
@@ -201,10 +201,10 @@ def test_rank_manager_integration(
         pass
     mock.assert_called_once_with(
         "test",
-        store_entire_run=False,
+        store_full=False,
         dry=False,
         dry_cache=False,
-        custom_name=None,
+        prefix=None,
         run_line="experiment test -p params1",
         parallel_lock=None,
         parallel_mode=expect_parallel,
@@ -235,7 +235,7 @@ def test_rank_manager_store_full_integration(
     clear_rank_env_vars,
 ):
     """A rank-zero process in a distributed run with store full should still set
-    'store_entire_run' on manager."""
+    'store_full' on manager."""
     if local_rank is not None:
         os.environ["LOCAL_RANK"] = str(local_rank)
     if node_rank is not None:
@@ -244,7 +244,7 @@ def test_rank_manager_store_full_integration(
     mock = mocker.patch.object(ArtifactManager, "__init__", return_value=None)
     try:
         run_experiment(
-            experiment_name="test", parameters_list=["params1"], store_entire_run=True
+            experiment_name="test", parameters_list=["params1"], store_full=True
         )
     except AttributeError:
         # NOTE: I'm not actually sure a better way around this, all I want to test is that
@@ -252,10 +252,10 @@ def test_rank_manager_store_full_integration(
         pass
     mock.assert_called_once_with(
         "test",
-        store_entire_run=expect_store_full,
+        store_full=expect_store_full,
         dry=False,
         dry_cache=False,
-        custom_name=None,
+        prefix=None,
         run_line="experiment test -p params1 --store-full",
         parallel_lock=None,
         parallel_mode=expect_parallel,
